Learn R Programming

heiscore.data (version 0.0.1)

HEI_scoring_standards: HEI-2020 Scoring Standards

Description

A table outlining the criteria for achieving the maximum HEI score in each of the 13 components for individuals ages 2 years or older.

Usage

HEI_scoring_standards

Arguments

Format

HEI_scoring_standards

A data frame with 13 rows and 6 columns:

component

HEI Component

max_points

The maximum number of points alloted to the HEI component

max_amount

The amount of the HEI component required to earn a maximum component score

zero_score

The amount of the HEI component that would earn 0 points towards the component score

unit

The HEI component's unit of measurement

component_type

Whether the HEI component is an 'adequacy' or 'moderation' type