A table outlining the criteria for achieving the maximum HEI score in each of the 13 components for individuals ages 2 years or older.
HEI_scoring_standardsHEI_scoring_standards
A data frame with 13 rows and 6 columns:
HEI Component
The maximum number of points alloted to the HEI component
The amount of the HEI component required to earn a maximum component score
The amount of the HEI component that would earn 0 points towards the component score
The HEI component's unit of measurement
Whether the HEI component is an 'adequacy' or 'moderation' type