A table outlining the criteria for achieving the maximum HEI score in each of the 13 components for young children, ages 12 through 23 months.
HEI_scoring_standards_toddlersHEI_scoring_standards_toddlers
A data frame with 13 rows and 6 columns:
HEI Component
The maximum number of points alloted to the HEI component
The amount of the HEI component required to earn a maximum component score
The amount of the HEI component that would earn 0 points towards the component score
The HEI component's unit of measurement
Whether the HEI component is an 'adequacy' or 'moderation' type